LDMSD Configuration Example files
=================================
- `simple_sampler.conf` is a simple configuration example of a sampler daemon.
- `simple_agg.conf` is a simple configuration example of an aggregator.
- `agg.conf` is a more complicated configuration example of an aggregator. It
  will configure an ldmsd to aggregate metric sets from running sampler daemons
  on the student and instructor VMs.
---------------------------------

simple_sampler.conf
=============
```
load name=meminfo
```
- Load the meminfo plugin

```
config name=meminfo producer=ovis-demo instance=ovis-demo_10001/meminfo component_id=0
```
- Configure the meminfo plugin to create an LDMS set.
  - The name is `ovis-demo_10001/meminfo`
  - The node origin of the set is `ovis-demo`.
  - The component ID associated with this set is 0.

```
start name=meminfo interval=1000000 offset=0
```
- Start the meminfo plugin. It will sample the values every 1 second. The given
  number is in microseconds. The offset of each second is 0.

---------------------------------

simple_agg.conf
=================================

Connection section
---------------------------------
```
prdcr_add name=localhost type=active host=localhost port=10001 xprt=sock interval=20000000
```
- Add a producer to connection to a sampler daemon. The producer in an
  aggregator represents a connection policy to an LDMS daemon.
  - The producer name in this command is independent from the producer name in
    LDMS sets created on sampler daemons.
  - The connection will connect to the sampler daemon on host `localhost`
    that is listening on port 10001.
  - The connection will use `socket` transport.
  - The type of the connection is `active` which means the aggregator will
    initiate the connection request.
    - The `passive` means the aggregator will wait for a connection request
      instead.
    - The `local` means the aggregator will create a dummy connection to
      represent the connection to itself.

```
prdcr_start_regex regex=.*
```
- Start all added producers

----------------------------------

Updater section
----------------------------------
```
updtr_add name=all interval=1000000 offset=200000
```
- Add an Updater policy called `all`. 
  - It will pull metric sets every 1 second at the millisecond 200 of each
    second.

```
updtr_prdcr_add name=all regex=.*
```
- The `all` Updater will be applied on all added producers in the Connection section.

```
updtr_start name=all
```
- Start the Updater `all`.

-----------------------------------

Storage section
-----------------------------------
```
load name=store_sos
```
- Load the SOS storage plugin.

```
config name=store_sos path=/home/ovis_public/demo/data/sos
```
- Configure the sos storage plugin so that it will create a database at the
  given path.

```
strgp_add name=meminfo schema=meminfo plugin=store_sos container=meminfo
```

- Add a storage policy, called `meminfo`.
  - It will store the LDMS sets that has the schema `meminfo`.
  - It will use the SOS storage plugin to store the numeric data.
  - The container of the metrics is called `meminfo`. The container value is
    used differently by storage plugins.

```
strgp_start name=meminfo
```
- Start the Storage policy `meminfo`. The meminfo sets will be stored when this command is called.
